#11565: Fix several typos. Patch by Piotr Kasprzyk.
diff --git a/Modules/socketmodule.c b/Modules/socketmodule.c
index 9bdca0c..b04d246 100644
--- a/Modules/socketmodule.c
+++ b/Modules/socketmodule.c
@@ -2151,7 +2151,7 @@
  * This is the guts of the recv() and recv_into() methods, which reads into a
  * char buffer.  If you have any inc/dec ref to do to the objects that contain
  * the buffer, do it in the caller.  This function returns the number of bytes
  * succesfully read.  If there was an error, it returns -1.  Note that it is
  * also possible that we return a number of bytes smaller than the request
  * bytes.
  */
@@ -2350,7 +2350,7 @@
  * This is the guts of the recvfrom() and recvfrom_into() methods, which reads
  * into a char buffer.  If you have any inc/def ref to do to the objects that
  * contain the buffer, do it in the caller.  This function returns the number
  * of bytes succesfully read.  If there was an error, it returns -1.  Note
  * that it is also possible that we return a number of bytes smaller than the
  * request bytes.
  *
@@ -2443,9 +2443,9 @@
 
     if (outlen != recvlen) {
         /* We did not read as many bytes as we anticipated, resize the
-           string if possible and be succesful. */
+           string if possible and be successful. */
         if (_PyBytes_Resize(&buf, outlen) < 0)
             /* Oopsy, not so succesful after all. */
             goto finally;
     }
 
@@ -4162,7 +4162,7 @@
 
     return 0;  /* Failure */
 #else
-    /* No need to initialise sockets with GCC/EMX */
+    /* No need to initialize sockets with GCC/EMX */
     return 1; /* Success */
 #endif
 }
@@ -4195,7 +4195,7 @@
    "socket.py" which implements some additional functionality.
    The import of "_socket" may fail with an ImportError exception if
    os-specific initialization fails.  On Windows, this does WINSOCK
-   initialization.  When WINSOCK is initialized succesfully, a call to
+   initialization.  When WINSOCK is initialized successfully, a call to
    WSACleanup() is scheduled to be made at exit time.
 */
@@ -2151,7 +2151,7 @@
  * char buffer.  If you have any inc/dec ref to do to the objects that contain
  * the buffer, do it in the caller.  This function returns the number of bytes
- * succesfully read.  If there was an error, it returns -1.  Note that it is
+ * successfully read.  If there was an error, it returns -1.  Note that it is
  * also possible that we return a number of bytes smaller than the request
  * bytes.
@@ -2350,7 +2350,7 @@
  * into a char buffer.  If you have any inc/def ref to do to the objects that
  * contain the buffer, do it in the caller.  This function returns the number
- * of bytes succesfully read.  If there was an error, it returns -1.  Note
+ * of bytes successfully read.  If there was an error, it returns -1.  Note
  * that it is also possible that we return a number of bytes smaller than the
  * request bytes.
@@ -2443,9 +2443,9 @@
         if (_PyBytes_Resize(&buf, outlen) < 0)
-            /* Oopsy, not so succesful after all. */
+            /* Oopsy, not so successful after all. */
             goto finally;
     }